# twiz
Your Twitter Account Data Analysis &amp; Visualization Tool &lt;3

## motivation

Being a data hunter ( yeah, you read it correct ), I love to collect available data & analyze it for finding hidden patterns in it.

That's why I downloaded my Twitter account data & started analyzing it. This tool can be used for analyzing your twitter account data without sending any of it to remote machines.

I'm adding some features here, if you feel some improvements can be done there, please feel free to contact me or you can always raise a PR.

## usage

During this early days of development, I'm not planning to publish it on PyPI. But later it'll be made available there. Now you can test it on your machine by cloning this repository.

## features

- Follwers & Followings
    - [x] [Twitter Followers And Followings Per Cent](./docs/twitterFollowersAndFollowingsPerCent.md)
    - [x] [Twitter Followers & Followers whom you're following vs Twitter Followings & Followings who're following you](./docs/twitterFollowersFollowingsAndIntersectionForYOU.md)

**This section will keep getting populated ;)**
